***************************
API reference
***************************

DataFrame & Series related functions
====================================

.. autosummary::
   :toctree: both

   trashpanda.add_blank_rows
   trashpanda.get_intersection
   trashpanda.cut_after
   trashpanda.cut_before

Series related functions
========================

.. autosummary::
   :toctree: series

   trashpanda.add_missing_indexes_to_series
   trashpanda.cut_series_after_max
   trashpanda.find_index_of_value_in_series
   trashpanda.override_left_with_right_series

DataFrame related functions
===========================

.. autosummary::
   :toctree: dataframe

   trashpanda.add_columns_to_dataframe
   trashpanda.cut_dataframe_after_max
   trashpanda.override_left_with_right_dataframe
